@@ -23,43 +23,27 @@ using System;
 using System.Collections.Generic;
 using Mono.Unix;
 
-using Do.Addins;
 using Do.Universe;
+using Do.Platform.Linux;
 
 namespace Flickr
 {	
-	public class FlickrItemSource : IItemSource, IConfigurable
+	public class FlickrItemSource : ItemSource, IConfigurable
 	{	
-		public string Name {
+		public override string Name {
 			get { return Catalog.GetString ("Account"); }
 		}
 		
-		public string Description {
+		public override string Description {
 			get { return ""; }
 		}
 		
-		public string Icon {
+		public override string Icon {
 			get { return "flickr.png@" + GetType ().Assembly.FullName; }
 		}
 		
-		public Type [] SupportedItemTypes {
-			get {
-				return new Type [] { };
-			}
-		}
-		
-		public ICollection<IItem> Items
-		{
-			get { return null; }
-		}
-		
-		public ICollection<IItem> ChildrenOfItem (IItem parent)
-		{
-			return null;
-		}
-		
-		public void UpdateItems ()
-		{
+		public override IEnumerable<Type> SupportedItemTypes {
+			get { yield break; }
 		}
 		
 		public Gtk.Bin GetConfiguration ()
