@@ -19,23 +19,23 @@
  */
 
 using System;
-using Do.Addins;
+
 using Do.Universe;
 using Mono.Unix;
 
 namespace VolumeControl
 {
-	public class VolumeMuteItem : IRunnableItem
+	public class VolumeMuteItem : Item, IRunnableItem
 	{
-		public string Name {
+		public override string Name {
 			get { return Catalog.GetString ("Mute Volume"); }
 		}
 		
-		public string Description {
+		public override string Description {
 			get { return Catalog.GetString ("Mute system volume"); }
 		}
 		
-		public string Icon {
+		public override string Icon {
 			get { return "audio-volume-muted"; }
 		}
 		
