@@ -20,23 +20,23 @@
 
 
 using System;
-using Do.Addins;
+
 using Do.Universe;
 using Mono.Unix;
 
 namespace VolumeControl
 {
-	public class VolumeUnmuteItem : IRunnableItem
+	public class VolumeUnmuteItem : Item, IRunnableItem
 	{
-		public string Name {
+		public override string Name {
 			get { return Catalog.GetString ("Unmute Volume"); }
 		}
 		
-		public string Description {
+		public override string Description {
 			get { return Catalog.GetString ("Unmute system volume"); }
 		}
 		
-		public string Icon {
+		public override string Icon {
 			get { return "audio-volume-medium"; }
 		}
 		
