@@ -19,23 +19,23 @@
  */
 
 using System;
-using Do.Addins;
+
 using Do.Universe;
 using Mono.Unix;
 
 namespace VolumeControl
 {
-	public class VolumeUpItem : IRunnableItem
+	public class VolumeUpItem : Item, IRunnableItem
 	{
-		public string Name {
+		public override string Name {
 			get { return Catalog.GetString ("Volume Up"); }
 		}
 		
-		public string Description {
+		public override string Description {
 			get { return Catalog.GetString ("Increase system volume"); }
 		}
 		
-		public string Icon {
+		public override string Icon {
 			get { return "audio-volume-high"; }
 		}
 		
